@@ -8,7 +8,6 @@ from tesserocr import (
 
 from ocrd_utils import (
     getLogger,
-    concat_padded,
     make_file_id,
     assert_file_grp_cardinality,
     coordinates_for_segment,
@@ -19,21 +18,17 @@ from ocrd_utils import (
 )
 from ocrd_modelfactory import page_from_file
 from ocrd_models.ocrd_page import (
-    MetadataItemType,
-    LabelsType, LabelType,
     CoordsType,
     TextRegionType,
     to_xml)
 from ocrd_models.ocrd_page_generateds import (
-    TableRegionType,
     TextTypeSimpleType,
     RegionRefType,
     RegionRefIndexedType,
     OrderedGroupType,
     OrderedGroupIndexedType,
     UnorderedGroupType,
-    UnorderedGroupIndexedType,
-    ReadingOrderType
+    UnorderedGroupIndexedType
 )
 from ocrd import Processor
 
@@ -79,21 +74,9 @@ class TesserocrSegmentTable(Processor):
                 page_id = input_file.pageId or input_file.ID
                 LOG.info("INPUT FILE %i / %s", n, page_id)
                 pcgts = page_from_file(self.workspace.download_file(input_file))
+                self.add_metadata(pcgts)
                 page = pcgts.get_Page()
                 
-                # add metadata about this operation and its runtime parameters:
-                metadata = pcgts.get_Metadata() # ensured by from_file()
-                metadata.add_MetadataItem(
-                    MetadataItemType(type_="processingStep",
-                                     name=self.ocrd_tool['steps'][0],
-                                     value=TOOL,
-                                     Labels=[LabelsType(
-                                         externalModel="ocrd-tool",
-                                         externalId="parameters",
-                                         Label=[LabelType(type_=name,
-                                                          value=self.parameter[name])
-                                                for name in self.parameter.keys()])]))
-
                 page_image, page_coords, page_image_info = self.workspace.image_from_page(
                     page, page_id)
                 if self.parameter['dpi'] > 0:
